==> istio-model-v1beta1-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/DestinationRuleSpecBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DestinationRuleSpecBuilder extends DestinationRuleSpecFluentImpl<DestinationRuleSpecBuilder> implements VisitableBuilder<DestinationRuleSpec,DestinationRuleSpecBuilder>{
  public DestinationRuleSpecBuilder() {
    this(false);
  }
  public DestinationRuleSpecBuilder(Boolean validationEnabled) {
    this(new DestinationRuleSpec(), validationEnabled);
  }
  public DestinationRuleSpecBuilder(DestinationRuleSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public DestinationRuleSpecBuilder(DestinationRuleSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DestinationRuleSpec(), validationEnabled);
  }
  public DestinationRuleSpecBuilder(DestinationRuleSpecFluent<?> fluent,DestinationRuleSpec instance) {
    this(fluent, instance, false);
  }
  public DestinationRuleSpecBuilder(DestinationRuleSpecFluent<?> fluent,DestinationRuleSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withExportTo(instance.getExportTo());
      fluent.withHost(instance.getHost());
      fluent.withSubsets(instance.getSubsets());
      fluent.withTrafficPolicy(instance.getTrafficPolicy());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DestinationRuleSpecBuilder(DestinationRuleSpec instance) {
    this(instance,false);
  }
  public DestinationRuleSpecBuilder(DestinationRuleSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withExportTo(instance.getExportTo());
      this.withHost(instance.getHost());
      this.withSubsets(instance.getSubsets());
      this.withTrafficPolicy(instance.getTrafficPolicy());
    }
    this.validationEnabled = validationEnabled; 
  }
  DestinationRuleSpecFluent<?> fluent;
  Boolean validationEnabled;
  public DestinationRuleSpec build() {
    DestinationRuleSpec buildable = new DestinationRuleSpec(fluent.getExportTo(),fluent.getHost(),fluent.getSubsets(),fluent.getTrafficPolicy());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/DestinationRuleSpecBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DestinationRuleSpecBuilder extends DestinationRuleSpecFluent<DestinationRuleSpecBuilder> implements VisitableBuilder<DestinationRuleSpec,DestinationRuleSpecBuilder>{
  public DestinationRuleSpecBuilder() {
    this(false);
  }
  public DestinationRuleSpecBuilder(Boolean validationEnabled) {
    this(new DestinationRuleSpec(), validationEnabled);
  }
  public DestinationRuleSpecBuilder(DestinationRuleSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public DestinationRuleSpecBuilder(DestinationRuleSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DestinationRuleSpec(), validationEnabled);
  }
  public DestinationRuleSpecBuilder(DestinationRuleSpecFluent<?> fluent,DestinationRuleSpec instance) {
    this(fluent, instance, false);
  }
  public DestinationRuleSpecBuilder(DestinationRuleSpecFluent<?> fluent,DestinationRuleSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new DestinationRuleSpec());

    if (instance != null) {
      fluent.withExportTo(instance.getExportTo());
      fluent.withHost(instance.getHost());
      fluent.withSubsets(instance.getSubsets());
      fluent.withTrafficPolicy(instance.getTrafficPolicy());
      fluent.withExportTo(instance.getExportTo());
      fluent.withHost(instance.getHost());
      fluent.withSubsets(instance.getSubsets());
      fluent.withTrafficPolicy(instance.getTrafficPolicy());
    }
    this.validationEnabled = validationEnabled; 
  }
  public DestinationRuleSpecBuilder(DestinationRuleSpec instance) {
    this(instance,false);
  }
  public DestinationRuleSpecBuilder(DestinationRuleSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new DestinationRuleSpec());

    if (instance != null) {
      this.withExportTo(instance.getExportTo());
      this.withHost(instance.getHost());
      this.withSubsets(instance.getSubsets());
      this.withTrafficPolicy(instance.getTrafficPolicy());
      this.withExportTo(instance.getExportTo());
      this.withHost(instance.getHost());
      this.withSubsets(instance.getSubsets());
      this.withTrafficPolicy(instance.getTrafficPolicy());
    }
    this.validationEnabled = validationEnabled; 
  }
  DestinationRuleSpecFluent<?> fluent;
  Boolean validationEnabled;
  public DestinationRuleSpec build() {
    DestinationRuleSpec buildable = new DestinationRuleSpec(fluent.getExportTo(),fluent.getHost(),fluent.buildSubsets(),fluent.buildTrafficPolicy());
    return buildable;
  }
  
}
